==> apache-druid-0.22.0-src.tar.gz: apache-druid-0.22.0-src/indexing-service/src/main/java/org/apache/druid/indexing/hadoop/OverlordActionBasedUsedSegmentsRetriever.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.indexing.hadoop;

import com.google.common.base.Preconditions;
import com.google.inject.Inject;
import org.apache.druid.indexer.path.UsedSegmentsRetriever;
import org.apache.druid.indexing.common.TaskToolbox;
import org.apache.druid.indexing.common.actions.RetrieveUsedSegmentsAction;
import org.apache.druid.indexing.overlord.Segments;
import org.apache.druid.timeline.DataSegment;
import org.joda.time.Interval;

import java.io.IOException;
import java.util.Collection;
import java.util.List;

/**
 */
public class OverlordActionBasedUsedSegmentsRetriever implements UsedSegmentsRetriever
{
  private final TaskToolbox toolbox;

  @Inject
  public OverlordActionBasedUsedSegmentsRetriever(TaskToolbox toolbox)
  {
    this.toolbox = Preconditions.checkNotNull(toolbox, "null task toolbox");
  }

  @Override
  public Collection<DataSegment> retrieveUsedSegmentsForIntervals(
      String dataSource,
      List<Interval> intervals,
      Segments visibility
  ) throws IOException
  {
    return toolbox
        .getTaskActionClient()
        .submit(new RetrieveUsedSegmentsAction(dataSource, null, intervals, visibility));
  }
}

==> apache-druid-31.0.2-src.tar.gz: apache-druid-31.0.2-src/indexing-service/src/main/java/org/apache/druid/indexing/hadoop/OverlordActionBasedUsedSegmentsRetriever.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.indexing.hadoop;

import com.google.common.base.Preconditions;
import com.google.inject.Inject;
import org.apache.druid.indexer.path.UsedSegmentsRetriever;
import org.apache.druid.indexing.common.TaskToolbox;
import org.apache.druid.indexing.common.actions.RetrieveUsedSegmentsAction;
import org.apache.druid.indexing.overlord.Segments;
import org.apache.druid.timeline.DataSegment;
import org.joda.time.Interval;

import java.io.IOException;
import java.util.Collection;
import java.util.List;

/**
 */
public class OverlordActionBasedUsedSegmentsRetriever implements UsedSegmentsRetriever
{
  private final TaskToolbox toolbox;

  @Inject
  public OverlordActionBasedUsedSegmentsRetriever(TaskToolbox toolbox)
  {
    this.toolbox = Preconditions.checkNotNull(toolbox, "null task toolbox");
  }

  @Override
  public Collection<DataSegment> retrieveUsedSegmentsForIntervals(
      String dataSource,
      List<Interval> intervals,
      Segments visibility
  ) throws IOException
  {
    return toolbox
        .getTaskActionClient()
        .submit(new RetrieveUsedSegmentsAction(dataSource, intervals, visibility));
  }
}
